local EasyMCM = include("easyMCM.EasyMCM")

-- Create a placeholder page if EasyMCM is not installed.
if (EasyMCM == nil) or (EasyMCM.version < 1.4) then
    local function placeholderMCM(element)
        element:createLabel{text="Ce mod requiert Simple MCM version 1.4 ou suprieure."}
        local link = element:createTextSelect{text="Tlcharger Simple MCM"}
        link.color = tes3ui.getPalette("link_color")
        link.widget.idle = tes3ui.getPalette("link_color")
        link.widget.over = tes3ui.getPalette("link_over_color")
        link.widget.pressed = tes3ui.getPalette("link_pressed_color")
        link:register("mouseClick", function()
            os.execute("start https://confrerie-des-traducteurs.fr/morrowind/mods/ressources_communes/simple_mcm")
        end)
    end
    mwse.registerModConfig("Graphic Herbalism", {onCreate=placeholderMCM})
    return
end


-------------------
-- Utility Funcs --
-------------------
local config = require("graphicHerbalism.config")

local function getHerbalismObjects()
    local list = {}
    for obj in tes3.iterateObjects(tes3.objectType.container) do
        if obj.organic then
            list[#list+1] = (obj.baseObject or obj).id:lower()
        end
    end
    table.sort(list)
    return list
end

local function getVolumeAsInteger(self)
    return math.round(config.volume * 100)
end

local function setVolumeAsDecimal(self, value)
    config.volume = math.round(value / 100, 2)
end


----------------------
-- EasyMCM Template --
----------------------
local template = EasyMCM.createTemplate{name="Rcolte raliste"}
template:saveOnClose("graphicHerbalism", config)
template:register()

-- Preferences Page
local preferences = template:createSideBarPage{label="Prfrences"}
preferences.sidebar:createInfo{text="Rcolte raliste pour MWSE version 1.04"}

-- Sidebar Credits
local credits = preferences.sidebar:createCategory{label="Crdits :"}
credits:createHyperlink{
    text = "Greatness7 - scripts",
    exec = "start https://www.nexusmods.com/morrowind/users/64030?tab=user+files",
}
credits:createHyperlink{
    text = "Merlord - support du MCM",
    exec = "start https://www.nexusmods.com/morrowind/users/3040468?tab=user+files",
}
credits:createHyperlink{
    text = "NullCascade - support de MWSE",
    exec = "start https://www.nexusmods.com/morrowind/users/26153919?tab=user+files",
}
credits:createHyperlink{
    text = "Petethegoat - aide et retours sur les scripts",
    exec = "start https://www.nexusmods.com/morrowind/users/25319994?tab=user+files",
}
credits:createHyperlink{
    text = "Remiros - modles du MOP",
    exec = "start https://www.nexusmods.com/morrowind/users/899234?tab=user+files",
}
credits:createHyperlink{
    text = "Stuporstar - conversion et lissage des modles",
    exec = "start http://stuporstar.sarahdimento.com/",
}
credits:createHyperlink{
    text = "Sveng - tests et retours",
    exec = "start https://www.nexusmods.com/morrowind/users/1121630?tab=user+files",
}
credits:createHyperlink{
    text = "Gruntella - textures universelles du mod",
    exec = "start https://www.nexusmods.com/morrowind/users/2356095?tab=user+files",
}
credits:createHyperlink{
    text = "Skrawafunda and ManaUser - textures d'origine du mod",
    exec = "start https://www.nexusmods.com/morrowind/users/13100210?tab=user+files",
}
credits:createHyperlink{
    text = "Moranar - modles lisss",
    exec = "start https://www.nexusmods.com/morrowind/users/6676263?tab=user+files",
}
credits:createHyperlink{
    text = "Tyddy - modles lisss",
    exec = "start https://www.nexusmods.com/morrowind/users/3281858?tab=user+files",
}
credits:createHyperlink{
    text = "Articus - aide et retours sur les modles",
    exec = "start https://www.nexusmods.com/morrowind/users/51799631?tab=user+files",
}
credits:createHyperlink{
    text = "DassiD - amlioration des textures",
    exec = "start https://www.nexusmods.com/morrowind/users/6344059?tab=user+files",
}
credits:createHyperlink{
    text = "Nich et CJW-Craigor - Diverse Correct UV Ore",
    exec = "start http://mw.modhistory.com/download-1-13484",
}

-- Feature Toggles
local toggles = preferences:createCategory{label="Fonctionnalits activables"}
toggles:createOnOffButton{
    label = "Afficher les infobulles des ingrdients",
    description = "Afficher les infobulles des ingrdients\n\nDtermine si les infobulles des ingrdients sont ou non affiches lorsqu'un conteneur rcoltable valide est cibl.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "showTooltips",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Afficher le message de rcolte",
    description = "Afficher le message de rcolte\n\nDtermine si le message de rcolte est ou non affich aprs l'activation d'un conteneur rcoltable.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "showPickedMessage",
        table = config,
    },
}

-- Feature Controls
local controls = preferences:createCategory{label="Contrles des fonctionnalits"}
controls:createSlider{
    label = "Volume des bruitages : %s %%",
    description = "Vous permet d'attnuer le volume des bruits de ramassage d'ingrdients. 0 fait que vous n'entendrez aucun bruit, 100 jouera les sons  leur volume maximal.",
    variable = EasyMCM:createVariable{
        get = getVolumeAsInteger,
        set = setVolumeAsDecimal,
    },
}

-- Blacklist Page
template:createExclusionsPage{
    label = "Liste noire",
    description = "Tous les conteneurs organiques sont considrs comme tant de la flore. Les coffres de guilde sont par dfaut sur liste noire, tout comme plusieurs conteneurs provenant de Tamriel Rebuilt. D'autres peuvent tre ajouts manuellement via ce menu.",
    leftListLabel = "Liste noire ",
    rightListLabel = "Objets ",
    variable = EasyMCM:createTableVariable{
        id = "blacklist",
        table = config,
    },
    filters = {
        {callback = getHerbalismObjects},
    },
}

-- Whitelist Page
template:createExclusionsPage{
    label = "Liste blanche",
    description = "Les conteneurs scripts sont automatiquement ignors, mais peuvent tre activs dans ce menu. Les conteneurs modifis par Expanded Sounds de Piratelord sont par dfaut sur liste blanche. Faites attention si vous mettez sur cette liste des conteneurs avec des scripts utilisant la fonction OnActivate, car cela peut casser leurs scripts.",
    leftListLabel = "Liste blanche ",
    rightListLabel = "Objets ",
    variable = EasyMCM:createTableVariable{
        id = "whitelist",
        table = config,
    },
    filters = {
        {callback = getHerbalismObjects},
    },
}
